GoogleCloudAiplatformV1beta1Annotation

Struct GoogleCloudAiplatformV1beta1Annotation 

pub struct GoogleCloudAiplatformV1beta1Annotation {
    pub update_time: Option<DateTime<Utc>>,
    pub labels: Option<HashMap<String, String>>,
    pub etag: Option<String>,
    pub payload: Option<Value>,
    pub name: Option<String>,
    pub annotation_source: Option<GoogleCloudAiplatformV1beta1UserActionReference>,
    pub payload_schema_uri: Option<String>,
    pub create_time: Option<DateTime<Utc>>,
}
Used to assign specific AnnotationSpec to a particular area of a DataItem or the whole part of the DataItem.

This type is not used in any activity, and only used as part of another schema.

Fields

update_time: Option<DateTime<Utc>>

Output only. Timestamp when this Annotation was last updated.

labels: Option<HashMap<String, String>>

Optional. The labels with user-defined metadata to organize your Annotations. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Annotation(System labels are excluded). See https://goo.gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with “aiplatform.googleapis.com/” and are immutable. Following system labels exist for each Annotation: * “aiplatform.googleapis.com/annotation_set_name”: optional, name of the UI’s annotation set this Annotation belongs to. If not set, the Annotation is not visible in the UI. * “aiplatform.googleapis.com/payload_schema”: output only, its value is the payload_schema’s title.

etag: Option<String>

Optional. Used to perform consistent read-modify-write updates. If not set, a blind “overwrite” update happens.

payload: Option<Value>

Required. The schema of the payload can be found in payload_schema.

name: Option<String>

Output only. Resource name of the Annotation.

annotation_source: Option<GoogleCloudAiplatformV1beta1UserActionReference>

Output only. The source of the Annotation.

payload_schema_uri: Option<String>

Required. Google Cloud Storage URI points to a YAML file describing payload. The schema is defined as an OpenAPI 3.0.2 Schema Object. The schema files that can be used here are found in gs://google-cloud-aiplatform/schema/dataset/annotation/, note that the chosen schema must be consistent with the parent Dataset’s metadata.

create_time: Option<DateTime<Utc>>

Output only. Timestamp when this Annotation was created.