pub struct GoogleCloudAiplatformV1beta1AuthConfigGoogleServiceAccountConfig {
pub service_account: Option<String>,
}Expand description
Config for Google Service Account Authentication.
This type is not used in any activity, and only used as part of another schema.
Fields
service_account: Option<String>Optional. The service account that the extension execution service runs as. - If the service account is specified, the iam.serviceAccounts.getAccessToken permission should be granted to Vertex AI Extension Service Agent (https://cloud.google.com/vertex-ai/docs/general/access-control#service-agents) on the specified service account. - If not specified, the Vertex AI Extension Service Agent will be used to execute the Extension.