pub struct GoogleCloudAiplatformV1beta1AuthConfigOauthConfig {
pub access_token: Option<String>,
pub service_account: Option<String>,
}Expand description
Config for user oauth.
This type is not used in any activity, and only used as part of another schema.
Fields
access_token: Option<String>Access token for extension endpoint. Only used to propagate token from [[ExecuteExtensionRequest.runtime_auth_config]] at request time.
service_account: Option<String>The service account used to generate access tokens for executing the Extension. - If the service account is specified, the iam.serviceAccounts.getAccessToken permission should be granted to Vertex AI Extension Service Agent (https://cloud.google.com/vertex-ai/docs/general/access-control#service-agents) on the provided service account.