pub struct GoogleCloudAiplatformV1beta1BatchReadFeatureValuesRequestPassThroughField {
pub field_name: Option<String>,
}Expand description
Describe pass-through fields in read_instance source.
This type is not used in any activity, and only used as part of another schema.
Fields
field_name: Option<String>Required. The name of the field in the CSV header or the name of the column in BigQuery table. The naming restriction is the same as Feature.name.