pub struct GoogleCloudAiplatformV1beta1CreateFeatureRequest {
pub parent: Option<String>,
pub feature: Option<GoogleCloudAiplatformV1beta1Feature>,
pub feature_id: Option<String>,
}Expand description
Request message for FeaturestoreService.CreateFeature. Request message for FeatureRegistryService.CreateFeature.
This type is not used in any activity, and only used as part of another schema.
Fields
parent: Option<String>Required. The resource name of the EntityType or FeatureGroup to create a Feature. Format for entity_type as parent: projects/{project}/locations/{location}/featurestores/{featurestore}/entityTypes/{entity_type} Format for feature_group as parent: projects/{project}/locations/{location}/featureGroups/{feature_group}
feature: Option<GoogleCloudAiplatformV1beta1Feature>Required. The Feature to create.
feature_id: Option<String>Required. The ID to use for the Feature, which will become the final component of the Feature’s resource name. This value may be up to 128 characters, and valid characters are [a-z0-9_]. The first character cannot be a number. The value must be unique within an EntityType/FeatureGroup.