pub struct GoogleCloudAiplatformV1beta1CreateModelMonitoringJobRequest {
pub parent: Option<String>,
pub model_monitoring_job: Option<GoogleCloudAiplatformV1beta1ModelMonitoringJob>,
pub model_monitoring_job_id: Option<String>,
}Expand description
Request message for ModelMonitoringService.CreateModelMonitoringJob.
This type is not used in any activity, and only used as part of another schema.
Fields
parent: Option<String>Required. The parent of the ModelMonitoringJob. Format: projects/{project}/locations/{location}/modelMoniitors/{model_monitor}
model_monitoring_job: Option<GoogleCloudAiplatformV1beta1ModelMonitoringJob>Required. The ModelMonitoringJob to create
model_monitoring_job_id: Option<String>Optional. The ID to use for the Model Monitoring Job, which will become the final component of the model monitoring job resource name. The maximum length is 63 characters, and valid characters are /^[a-z]([a-z0-9-]{0,61}[a-z0-9])?$/.