pub struct GoogleCloudAiplatformV1beta1DeleteFeatureValuesRequestSelectEntity {
pub entity_id_selector: Option<GoogleCloudAiplatformV1beta1EntityIdSelector>,
}Expand description
Message to select entity. If an entity id is selected, all the feature values corresponding to the entity id will be deleted, including the entityId.
This type is not used in any activity, and only used as part of another schema.
Fields
entity_id_selector: Option<GoogleCloudAiplatformV1beta1EntityIdSelector>Required. Selectors choosing feature values of which entity id to be deleted from the EntityType.