pub struct GoogleCloudAiplatformV1beta1DeleteFeatureValuesRequestSelectTimeRangeAndFeature {
pub time_range: Option<GoogleTypeInterval>,
pub feature_selector: Option<GoogleCloudAiplatformV1beta1FeatureSelector>,
pub skip_online_storage_delete: Option<bool>,
}Expand description
Message to select time range and feature. Values of the selected feature generated within an inclusive time range will be deleted. Using this option permanently deletes the feature values from the specified feature IDs within the specified time range. This might include data from the online storage. If you want to retain any deleted historical data in the online storage, you must re-ingest it.
This type is not used in any activity, and only used as part of another schema.
Fields
time_range: Option<GoogleTypeInterval>Required. Select feature generated within a half-inclusive time range. The time range is lower inclusive and upper exclusive.
feature_selector: Option<GoogleCloudAiplatformV1beta1FeatureSelector>Required. Selectors choosing which feature values to be deleted from the EntityType.
skip_online_storage_delete: Option<bool>If set, data will not be deleted from online storage. When time range is older than the data in online storage, setting this to be true will make the deletion have no impact on online serving.