pub struct GoogleCloudAiplatformV1beta1DeployedIndexAuthConfigAuthProvider {
pub audiences: Option<Vec<String>>,
pub allowed_issuers: Option<Vec<String>>,
}Expand description
Configuration for an authentication provider, including support for JSON Web Token (JWT).
This type is not used in any activity, and only used as part of another schema.
Fields
audiences: Option<Vec<String>>The list of JWT audiences. that are allowed to access. A JWT containing any of these audiences will be accepted.
allowed_issuers: Option<Vec<String>>A list of allowed JWT issuers. Each entry must be a valid Google service account, in the following format: service-account-name@project-id.iam.gserviceaccount.com