pub struct GoogleCloudAiplatformV1beta1DirectUploadSource { /* private fields */ }Expand description
The input content is encapsulated and uploaded in the request.
This type is not used in any activity, and only used as part of another schema.