pub struct GoogleCloudAiplatformV1beta1ExplanationMetadataInputMetadataVisualization {
pub polarity: Option<String>,
pub color_map: Option<String>,
pub clip_percent_lowerbound: Option<f32>,
pub type_: Option<String>,
pub overlay_type: Option<String>,
pub clip_percent_upperbound: Option<f32>,
}Expand description
Visualization configurations for image explanation.
This type is not used in any activity, and only used as part of another schema.
Fields
polarity: Option<String>Whether to only highlight pixels with positive contributions, negative or both. Defaults to POSITIVE.
color_map: Option<String>The color scheme used for the highlighted areas. Defaults to PINK_GREEN for Integrated Gradients attribution, which shows positive attributions in green and negative in pink. Defaults to VIRIDIS for XRAI attribution, which highlights the most influential regions in yellow and the least influential in blue.
clip_percent_lowerbound: Option<f32>Excludes attributions below the specified percentile, from the highlighted areas. Defaults to 62.
type_: Option<String>Type of the image visualization. Only applicable to Integrated Gradients attribution. OUTLINES shows regions of attribution, while PIXELS shows per-pixel attribution. Defaults to OUTLINES.
overlay_type: Option<String>How the original image is displayed in the visualization. Adjusting the overlay can help increase visual clarity if the original image makes it difficult to view the visualization. Defaults to NONE.
clip_percent_upperbound: Option<f32>Excludes attributions above the specified percentile from the highlighted areas. Using the clip_percent_upperbound and clip_percent_lowerbound together can be useful for filtering out noise and making it easier to see areas of strong attribution. Defaults to 99.9.