GoogleCloudAiplatformV1beta1ExportDataConfig

Struct GoogleCloudAiplatformV1beta1ExportDataConfig 

pub struct GoogleCloudAiplatformV1beta1ExportDataConfig {
    pub fraction_split: Option<GoogleCloudAiplatformV1beta1ExportFractionSplit>,
    pub annotations_filter: Option<String>,
    pub gcs_destination: Option<GoogleCloudAiplatformV1beta1GcsDestination>,
}
Describes what part of the Dataset is to be exported, the destination of the export and how to export.

This type is not used in any activity, and only used as part of another schema.

Fields

fraction_split: Option<GoogleCloudAiplatformV1beta1ExportFractionSplit>

Split based on fractions defining the size of each set.

annotations_filter: Option<String>

An expression for filtering what part of the Dataset is to be exported. Only Annotations that match this filter will be exported. The filter syntax is the same as in ListAnnotations.

gcs_destination: Option<GoogleCloudAiplatformV1beta1GcsDestination>

The Google Cloud Storage location where the output is to be written to. In the given directory a new directory will be created with name: export-data-- where timestamp is in YYYY-MM-DDThh:mm:ss.sssZ ISO-8601 format. All export output will be written into that directory. Inside that directory, annotations with the same schema will be grouped into sub directories which are named with the corresponding annotations’ schema title. Inside these sub directories, a schema.yaml will be created to describe the output format.