pub struct GoogleCloudAiplatformV1beta1ExportFeatureValuesRequestFullExport {
pub end_time: Option<DateTime<Utc>>,
pub start_time: Option<DateTime<Utc>>,
}Expand description
Describes exporting all historical Feature values of all entities of the EntityType between [start_time, end_time].
This type is not used in any activity, and only used as part of another schema.
Fields
end_time: Option<DateTime<Utc>>Exports Feature values as of this timestamp. If not set, retrieve values as of now. Timestamp, if present, must not have higher than millisecond precision.
start_time: Option<DateTime<Utc>>Excludes Feature values with feature generation timestamp before this timestamp. If not set, retrieve oldest values kept in Feature Store. Timestamp, if present, must not have higher than millisecond precision.