pub struct GoogleCloudAiplatformV1beta1FeatureValueDestination {
pub tfrecord_destination: Option<GoogleCloudAiplatformV1beta1TFRecordDestination>,
pub csv_destination: Option<GoogleCloudAiplatformV1beta1CsvDestination>,
pub bigquery_destination: Option<GoogleCloudAiplatformV1beta1BigQueryDestination>,
}Expand description
A destination location for Feature values and format.
This type is not used in any activity, and only used as part of another schema.
Fields
tfrecord_destination: Option<GoogleCloudAiplatformV1beta1TFRecordDestination>Output in TFRecord format. Below are the mapping from Feature value type in Featurestore to Feature value type in TFRecord: Value type in Featurestore | Value type in TFRecord DOUBLE, DOUBLE_ARRAY | FLOAT_LIST INT64, INT64_ARRAY | INT64_LIST STRING, STRING_ARRAY, BYTES | BYTES_LIST true -> byte_string(“true”), false -> byte_string(“false”) BOOL, BOOL_ARRAY (true, false) | BYTES_LIST
csv_destination: Option<GoogleCloudAiplatformV1beta1CsvDestination>Output in CSV format. Array Feature value types are not allowed in CSV format.
bigquery_destination: Option<GoogleCloudAiplatformV1beta1BigQueryDestination>Output in BigQuery format. BigQueryDestination.output_uri in FeatureValueDestination.bigquery_destination must refer to a table.