pub struct GoogleCloudAiplatformV1beta1FeatureValueMetadata {
pub generate_time: Option<DateTime<Utc>>,
}Expand description
Metadata of feature value.
This type is not used in any activity, and only used as part of another schema.
Fields
generate_time: Option<DateTime<Utc>>Feature generation timestamp. Typically, it is provided by user at feature ingestion time. If not, feature store will use the system timestamp when the data is ingested into feature store. For streaming ingestion, the time, aligned by days, must be no older than five years (1825 days) and no later than one year (366 days) in the future.