pub struct GoogleCloudAiplatformV1beta1FeatureViewFeatureRegistrySource {
pub project_number: Option<i64>,
pub feature_groups: Option<Vec<GoogleCloudAiplatformV1beta1FeatureViewFeatureRegistrySourceFeatureGroup>>,
}Expand description
A Feature Registry source for features that need to be synced to Online Store.
This type is not used in any activity, and only used as part of another schema.
Fields
project_number: Option<i64>Optional. The project number of the parent project of the Feature Groups.
feature_groups: Option<Vec<GoogleCloudAiplatformV1beta1FeatureViewFeatureRegistrySourceFeatureGroup>>Required. List of features that need to be synced to Online Store.