pub struct GoogleCloudAiplatformV1beta1FeatureViewIndexConfig {
pub embedding_dimension: Option<i32>,
pub distance_measure_type: Option<String>,
pub brute_force_config: Option<GoogleCloudAiplatformV1beta1FeatureViewIndexConfigBruteForceConfig>,
pub crowding_column: Option<String>,
pub filter_columns: Option<Vec<String>>,
pub embedding_column: Option<String>,
pub tree_ah_config: Option<GoogleCloudAiplatformV1beta1FeatureViewIndexConfigTreeAHConfig>,
}Expand description
Configuration for vector indexing.
This type is not used in any activity, and only used as part of another schema.
Fields
embedding_dimension: Option<i32>Optional. The number of dimensions of the input embedding.
distance_measure_type: Option<String>Optional. The distance measure used in nearest neighbor search.
brute_force_config: Option<GoogleCloudAiplatformV1beta1FeatureViewIndexConfigBruteForceConfig>Optional. Configuration options for using brute force search, which simply implements the standard linear search in the database for each query. It is primarily meant for benchmarking and to generate the ground truth for approximate search.
crowding_column: Option<String>Optional. Column of crowding. This column contains crowding attribute which is a constraint on a neighbor list produced by FeatureOnlineStoreService.SearchNearestEntities to diversify search results. If NearestNeighborQuery.per_crowding_attribute_neighbor_count is set to K in SearchNearestEntitiesRequest, it’s guaranteed that no more than K entities of the same crowding attribute are returned in the response.
filter_columns: Option<Vec<String>>Optional. Columns of features that’re used to filter vector search results.
embedding_column: Option<String>Optional. Column of embedding. This column contains the source data to create index for vector search. embedding_column must be set when using vector search.
tree_ah_config: Option<GoogleCloudAiplatformV1beta1FeatureViewIndexConfigTreeAHConfig>Optional. Configuration options for the tree-AH algorithm (Shallow tree + Asymmetric Hashing). Please refer to this paper for more details: https://arxiv.org/abs/1908.10396