pub struct GoogleCloudAiplatformV1beta1FeaturestoreMonitoringConfig {
pub numerical_threshold_config: Option<GoogleCloudAiplatformV1beta1FeaturestoreMonitoringConfigThresholdConfig>,
pub categorical_threshold_config: Option<GoogleCloudAiplatformV1beta1FeaturestoreMonitoringConfigThresholdConfig>,
pub snapshot_analysis: Option<GoogleCloudAiplatformV1beta1FeaturestoreMonitoringConfigSnapshotAnalysis>,
pub import_features_analysis: Option<GoogleCloudAiplatformV1beta1FeaturestoreMonitoringConfigImportFeaturesAnalysis>,
}Expand description
Configuration of how features in Featurestore are monitored.
This type is not used in any activity, and only used as part of another schema.
Fields
numerical_threshold_config: Option<GoogleCloudAiplatformV1beta1FeaturestoreMonitoringConfigThresholdConfig>Threshold for numerical features of anomaly detection. This is shared by all objectives of Featurestore Monitoring for numerical features (i.e. Features with type (Feature.ValueType) DOUBLE or INT64).
categorical_threshold_config: Option<GoogleCloudAiplatformV1beta1FeaturestoreMonitoringConfigThresholdConfig>Threshold for categorical features of anomaly detection. This is shared by all types of Featurestore Monitoring for categorical features (i.e. Features with type (Feature.ValueType) BOOL or STRING).
snapshot_analysis: Option<GoogleCloudAiplatformV1beta1FeaturestoreMonitoringConfigSnapshotAnalysis>The config for Snapshot Analysis Based Feature Monitoring.
import_features_analysis: Option<GoogleCloudAiplatformV1beta1FeaturestoreMonitoringConfigImportFeaturesAnalysis>The config for ImportFeatures Analysis Based Feature Monitoring.