pub struct GoogleCloudAiplatformV1beta1FeaturestoreMonitoringConfigImportFeaturesAnalysis {
pub state: Option<String>,
pub anomaly_detection_baseline: Option<String>,
}Expand description
Configuration of the Featurestore’s ImportFeature Analysis Based Monitoring. This type of analysis generates statistics for values of each Feature imported by every ImportFeatureValues operation.
This type is not used in any activity, and only used as part of another schema.
Fields
state: Option<String>Whether to enable / disable / inherite default hebavior for import features analysis.
anomaly_detection_baseline: Option<String>The baseline used to do anomaly detection for the statistics generated by import features analysis.