GoogleCloudAiplatformV1beta1FunctionDeclaration

Struct GoogleCloudAiplatformV1beta1FunctionDeclaration 

pub struct GoogleCloudAiplatformV1beta1FunctionDeclaration {
    pub parameters: Option<GoogleCloudAiplatformV1beta1Schema>,
    pub name: Option<String>,
    pub description: Option<String>,
    pub response: Option<GoogleCloudAiplatformV1beta1Schema>,
}
Structured representation of a function declaration as defined by the OpenAPI 3.0 specification. Included in this declaration are the function name and parameters. This FunctionDeclaration is a representation of a block of code that can be used as a Tool by the model and executed by the client.

This type is not used in any activity, and only used as part of another schema.

Fields

parameters: Option<GoogleCloudAiplatformV1beta1Schema>

Optional. Describes the parameters to this function in JSON Schema Object format. Reflects the Open API 3.03 Parameter Object. string Key: the name of the parameter. Parameter names are case sensitive. Schema Value: the Schema defining the type used for the parameter. For function with no parameters, this can be left unset. Parameter names must start with a letter or an underscore and must only contain chars a-z, A-Z, 0-9, or underscores with a maximum length of 64. Example with 1 required and 1 optional parameter: type: OBJECT properties: param1: type: STRING param2: type: INTEGER required: - param1

name: Option<String>

Required. The name of the function to call. Must start with a letter or an underscore. Must be a-z, A-Z, 0-9, or contain underscores, dots and dashes, with a maximum length of 64.

description: Option<String>

Optional. Description and purpose of the function. Model uses it to decide how and whether to call the function.

response: Option<GoogleCloudAiplatformV1beta1Schema>

Optional. Describes the output from this function in JSON Schema format. Reflects the Open API 3.03 Response Object. The Schema defines the type used for the response value of the function.