GoogleCloudAiplatformV1beta1IndexDatapointNumericRestriction

Struct GoogleCloudAiplatformV1beta1IndexDatapointNumericRestriction 

pub struct GoogleCloudAiplatformV1beta1IndexDatapointNumericRestriction {
    pub value_double: Option<f64>,
    pub namespace: Option<String>,
    pub value_float: Option<f32>,
    pub op: Option<String>,
    pub value_int: Option<i64>,
}
This field allows restricts to be based on numeric comparisons rather than categorical tokens.

This type is not used in any activity, and only used as part of another schema.

Fields

value_double: Option<f64>

Represents 64 bit float.

namespace: Option<String>

The namespace of this restriction. e.g.: cost.

value_float: Option<f32>

Represents 32 bit float.

op: Option<String>

This MUST be specified for queries and must NOT be specified for datapoints.

value_int: Option<i64>

Represents 64 bit integer.