pub struct GoogleCloudAiplatformV1beta1IndexDatapointSparseEmbedding {
pub dimensions: Option<Vec<i64>>,
pub values: Option<Vec<f32>>,
}Expand description
Feature embedding vector for sparse index. An array of numbers whose values are located in the specified dimensions.
This type is not used in any activity, and only used as part of another schema.
Fields
dimensions: Option<Vec<i64>>Required. The list of indexes for the embedding values of the sparse vector.
values: Option<Vec<f32>>Required. The list of embedding values of the sparse vector.