pub struct GoogleCloudAiplatformV1beta1MachineSpec {
pub machine_type: Option<String>,
pub accelerator_count: Option<i32>,
pub tpu_topology: Option<String>,
pub accelerator_type: Option<String>,
}Expand description
Specification of a single machine.
This type is not used in any activity, and only used as part of another schema.
Fields
machine_type: Option<String>Immutable. The type of the machine. See the list of machine types supported for prediction See the list of machine types supported for custom training. For DeployedModel this field is optional, and the default value is n1-standard-2. For BatchPredictionJob or as part of WorkerPoolSpec this field is required.
accelerator_count: Option<i32>The number of accelerators to attach to the machine.
tpu_topology: Option<String>Immutable. The topology of the TPUs. Corresponds to the TPU topologies available from GKE. (Example: tpu_topology: “2x2x1”).
accelerator_type: Option<String>Immutable. The type of accelerator(s) that may be attached to the machine as per accelerator_count.