pub struct GoogleCloudAiplatformV1beta1ModelBaseModelSource {
pub genie_source: Option<GoogleCloudAiplatformV1beta1GenieSource>,
pub model_garden_source: Option<GoogleCloudAiplatformV1beta1ModelGardenSource>,
}Expand description
User input field to specify the base model source. Currently it only supports specifing the Model Garden models and Genie models.
This type is not used in any activity, and only used as part of another schema.
Fields
genie_source: Option<GoogleCloudAiplatformV1beta1GenieSource>Information about the base model of Genie models.
model_garden_source: Option<GoogleCloudAiplatformV1beta1ModelGardenSource>Source information of Model Garden models.