pub struct GoogleCloudAiplatformV1beta1ModelDeploymentMonitoringBigQueryTable {
pub request_response_logging_schema_version: Option<String>,
pub log_type: Option<String>,
pub bigquery_table_path: Option<String>,
pub log_source: Option<String>,
}Expand description
ModelDeploymentMonitoringBigQueryTable specifies the BigQuery table name as well as some information of the logs stored in this table.
This type is not used in any activity, and only used as part of another schema.
Fields
request_response_logging_schema_version: Option<String>Output only. The schema version of the request/response logging BigQuery table. Default to v1 if unset.
log_type: Option<String>The type of log.
bigquery_table_path: Option<String>The created BigQuery table to store logs. Customer could do their own query & analysis. Format: bq://.model_deployment_monitoring_._
log_source: Option<String>The source of log.