pub struct GoogleCloudAiplatformV1beta1ModelExportFormat {
pub id: Option<String>,
pub exportable_contents: Option<Vec<String>>,
}Expand description
Represents export format supported by the Model. All formats export to Google Cloud Storage.
This type is not used in any activity, and only used as part of another schema.
Fields
id: Option<String>Output only. The ID of the export format. The possible format IDs are: * tflite Used for Android mobile devices. * edgetpu-tflite Used for Edge TPU devices. * tf-saved-model A tensorflow model in SavedModel format. * tf-js A TensorFlow.js model that can be used in the browser and in Node.js using JavaScript. * core-ml Used for iOS mobile devices. * custom-trained A Model that was uploaded or trained by custom code.
exportable_contents: Option<Vec<String>>Output only. The content of this Model that may be exported.