pub struct GoogleCloudAiplatformV1beta1ModelMonitorModelMonitoringTarget {
pub vertex_model: Option<GoogleCloudAiplatformV1beta1ModelMonitorModelMonitoringTargetVertexModelSource>,
}Expand description
The monitoring target refers to the entity that is subject to analysis. e.g. Vertex AI Model version.
This type is not used in any activity, and only used as part of another schema.
Fields
vertex_model: Option<GoogleCloudAiplatformV1beta1ModelMonitorModelMonitoringTargetVertexModelSource>Model in Vertex AI Model Registry.