pub struct GoogleCloudAiplatformV1beta1ModelMonitoringAlert {
pub anomaly: Option<GoogleCloudAiplatformV1beta1ModelMonitoringAnomaly>,
pub objective_type: Option<String>,
pub alert_time: Option<DateTime<Utc>>,
pub stats_name: Option<String>,
}Expand description
Represents a single monitoring alert. This is currently used in the SearchModelMonitoringAlerts api, thus the alert wrapped in this message belongs to the resource asked in the request.
This type is not used in any activity, and only used as part of another schema.
Fields
anomaly: Option<GoogleCloudAiplatformV1beta1ModelMonitoringAnomaly>Anomaly details.
objective_type: Option<String>One of the supported monitoring objectives: raw-feature-drift prediction-output-drift feature-attribution
alert_time: Option<DateTime<Utc>>Alert creation time.
stats_name: Option<String>The stats name.