GoogleCloudAiplatformV1beta1ModelMonitoringConfig

Struct GoogleCloudAiplatformV1beta1ModelMonitoringConfig 

pub struct GoogleCloudAiplatformV1beta1ModelMonitoringConfig {
    pub stats_anomalies_base_directory: Option<GoogleCloudAiplatformV1beta1GcsDestination>,
    pub alert_config: Option<GoogleCloudAiplatformV1beta1ModelMonitoringAlertConfig>,
    pub analysis_instance_schema_uri: Option<String>,
    pub objective_configs: Option<Vec<GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveConfig>>,
}
The model monitoring configuration used for Batch Prediction Job.

This type is not used in any activity, and only used as part of another schema.

Fields

stats_anomalies_base_directory: Option<GoogleCloudAiplatformV1beta1GcsDestination>

A Google Cloud Storage location for batch prediction model monitoring to dump statistics and anomalies. If not provided, a folder will be created in customer project to hold statistics and anomalies.

alert_config: Option<GoogleCloudAiplatformV1beta1ModelMonitoringAlertConfig>

Model monitoring alert config.

analysis_instance_schema_uri: Option<String>

YAML schema file uri in Cloud Storage describing the format of a single instance that you want Tensorflow Data Validation (TFDV) to analyze. If there are any data type differences between predict instance and TFDV instance, this field can be used to override the schema. For models trained with Vertex AI, this field must be set as all the fields in predict instance formatted as string.

objective_configs: Option<Vec<GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveConfig>>

Model monitoring objective config.