pub struct GoogleCloudAiplatformV1beta1ModelMonitoringInput {
pub batch_prediction_output: Option<GoogleCloudAiplatformV1beta1ModelMonitoringInputBatchPredictionOutput>,
pub time_offset: Option<GoogleCloudAiplatformV1beta1ModelMonitoringInputTimeOffset>,
pub time_interval: Option<GoogleTypeInterval>,
pub columnized_dataset: Option<GoogleCloudAiplatformV1beta1ModelMonitoringInputModelMonitoringDataset>,
pub vertex_endpoint_logs: Option<GoogleCloudAiplatformV1beta1ModelMonitoringInputVertexEndpointLogs>,
}Expand description
Model monitoring data input spec.
This type is not used in any activity, and only used as part of another schema.
Fields
batch_prediction_output: Option<GoogleCloudAiplatformV1beta1ModelMonitoringInputBatchPredictionOutput>Vertex AI Batch prediction Job.
time_offset: Option<GoogleCloudAiplatformV1beta1ModelMonitoringInputTimeOffset>The time offset setting for which results should be returned.
time_interval: Option<GoogleTypeInterval>The time interval (pair of start_time and end_time) for which results should be returned.
columnized_dataset: Option<GoogleCloudAiplatformV1beta1ModelMonitoringInputModelMonitoringDataset>Columnized dataset.
vertex_endpoint_logs: Option<GoogleCloudAiplatformV1beta1ModelMonitoringInputVertexEndpointLogs>Vertex AI Endpoint request & response logging.