pub struct GoogleCloudAiplatformV1beta1ModelMonitoringInputTimeOffset {
pub window: Option<String>,
pub offset: Option<String>,
}Expand description
Time offset setting.
This type is not used in any activity, and only used as part of another schema.
Fields
window: Option<String>[window] refers to the scope of data selected for analysis. It allows you to specify the quantity of data you wish to examine. Currently we support the following format: ‘w|W’: Week, ‘d|D’: Day, ‘h|H’: Hour E.g. ‘1h’ stands for 1 hour, ‘2d’ stands for 2 days.
offset: Option<String>[offset] is the time difference from the cut-off time. For scheduled jobs, the cut-off time is the scheduled time. For non-scheduled jobs, it’s the time when the job was created. Currently we support the following format: ‘w|W’: Week, ‘d|D’: Day, ‘h|H’: Hour E.g. ‘1h’ stands for 1 hour, ‘2d’ stands for 2 days.