Struct GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline
pub struct GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline {
pub prediction_format: Option<String>,
pub gcs: Option<GoogleCloudAiplatformV1beta1GcsDestination>,
pub bigquery: Option<GoogleCloudAiplatformV1beta1BigQueryDestination>,
}Expand description
Output from BatchPredictionJob for Model Monitoring baseline dataset, which can be used to generate baseline attribution scores.
This type is not used in any activity, and only used as part of another schema.
Fields
prediction_format: Option<String>The storage format of the predictions generated BatchPrediction job.
gcs: Option<GoogleCloudAiplatformV1beta1GcsDestination>Cloud Storage location for BatchExplain output.
bigquery: Option<GoogleCloudAiplatformV1beta1BigQueryDestination>BigQuery location for BatchExplain output.