Struct GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig
pub struct GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig {
pub skew_thresholds: Option<HashMap<String, GoogleCloudAiplatformV1beta1ThresholdConfig>>,
pub default_skew_threshold: Option<GoogleCloudAiplatformV1beta1ThresholdConfig>,
pub attribution_score_skew_thresholds: Option<HashMap<String, GoogleCloudAiplatformV1beta1ThresholdConfig>>,
}Expand description
The config for Training & Prediction data skew detection. It specifies the training dataset sources and the skew detection parameters.
This type is not used in any activity, and only used as part of another schema.
Fields
skew_thresholds: Option<HashMap<String, GoogleCloudAiplatformV1beta1ThresholdConfig>>Key is the feature name and value is the threshold. If a feature needs to be monitored for skew, a value threshold must be configured for that feature. The threshold here is against feature distribution distance between the training and prediction feature.
default_skew_threshold: Option<GoogleCloudAiplatformV1beta1ThresholdConfig>Skew anomaly detection threshold used by all features. When the per-feature thresholds are not set, this field can be used to specify a threshold for all features.
attribution_score_skew_thresholds: Option<HashMap<String, GoogleCloudAiplatformV1beta1ThresholdConfig>>Key is the feature name and value is the threshold. The threshold here is against attribution score distance between the training and prediction feature.