GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecDataDriftSpec

Struct GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecDataDriftSpec 

pub struct GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecDataDriftSpec {
    pub features: Option<Vec<String>>,
    pub categorical_metric_type: Option<String>,
    pub numeric_metric_type: Option<String>,
    pub default_numeric_alert_condition: Option<GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition>,
    pub default_categorical_alert_condition: Option<GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition>,
    pub feature_alert_conditions: Option<HashMap<String, GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition>>,
}
Data drift monitoring spec. Data drift measures the distribution distance between the current dataset and a baseline dataset. A typical use case is to detect data drift between the recent production serving dataset and the training dataset, or to compare the recent production dataset with a dataset from a previous period.

This type is not used in any activity, and only used as part of another schema.

Fields

features: Option<Vec<String>>

Feature names / Prediction output names interested in monitoring. These should be a subset of the input feature names or prediction output names specified in the monitoring schema. If the field is not specified all features / prediction outputs outlied in the monitoring schema will be used.

categorical_metric_type: Option<String>

Supported metrics type: * l_infinity * jensen_shannon_divergence

numeric_metric_type: Option<String>

Supported metrics type: * jensen_shannon_divergence

default_numeric_alert_condition: Option<GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition>

Default alert condition for all the numeric features.

default_categorical_alert_condition: Option<GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition>

Default alert condition for all the categorical features.

feature_alert_conditions: Option<HashMap<String, GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition>>

Per feature alert condition will override default alert condition.