GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecFeatureAttributionSpec

Struct GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecFeatureAttributionSpec 

pub struct GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecFeatureAttributionSpec {
    pub feature_alert_conditions: Option<HashMap<String, GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition>>,
    pub batch_explanation_dedicated_resources: Option<GoogleCloudAiplatformV1beta1BatchDedicatedResources>,
    pub default_alert_condition: Option<GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition>,
    pub features: Option<Vec<String>>,
}
Feature attribution monitoring spec.

This type is not used in any activity, and only used as part of another schema.

Fields

feature_alert_conditions: Option<HashMap<String, GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition>>

Per feature alert condition will override default alert condition.

batch_explanation_dedicated_resources: Option<GoogleCloudAiplatformV1beta1BatchDedicatedResources>

The config of resources used by the Model Monitoring during the batch explanation for non-AutoML models. If not set, n1-standard-2 machine type will be used by default.

default_alert_condition: Option<GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition>

Default alert condition for all the features.

features: Option<Vec<String>>

Feature names interested in monitoring. These should be a subset of the input feature names specified in the monitoring schema. If the field is not specified all features outlied in the monitoring schema will be used.