pub struct GoogleCloudAiplatformV1beta1ModelMonitoringSpec {
pub notification_spec: Option<GoogleCloudAiplatformV1beta1ModelMonitoringNotificationSpec>,
pub objective_spec: Option<GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpec>,
pub output_spec: Option<GoogleCloudAiplatformV1beta1ModelMonitoringOutputSpec>,
}Expand description
Monitoring monitoring job spec. It outlines the specifications for monitoring objectives, notifications, and result exports.
This type is not used in any activity, and only used as part of another schema.
Fields
notification_spec: Option<GoogleCloudAiplatformV1beta1ModelMonitoringNotificationSpec>The model monitoring notification spec.
objective_spec: Option<GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpec>The monitoring objective spec.
output_spec: Option<GoogleCloudAiplatformV1beta1ModelMonitoringOutputSpec>The Output destination spec for metrics, error logs, etc.