pub struct GoogleCloudAiplatformV1beta1ModelSourceInfo {
pub source_type: Option<String>,
pub copy: Option<bool>,
}Expand description
Detail description of the source information of the model.
This type is not used in any activity, and only used as part of another schema.
Fields
source_type: Option<String>Type of the model source.
copy: Option<bool>If this Model is copy of another Model. If true then source_type pertains to the original.