pub struct GoogleCloudAiplatformV1beta1NearestNeighborQuery {
pub entity_id: Option<String>,
pub neighbor_count: Option<i32>,
pub string_filters: Option<Vec<GoogleCloudAiplatformV1beta1NearestNeighborQueryStringFilter>>,
pub parameters: Option<GoogleCloudAiplatformV1beta1NearestNeighborQueryParameters>,
pub numeric_filters: Option<Vec<GoogleCloudAiplatformV1beta1NearestNeighborQueryNumericFilter>>,
pub embedding: Option<GoogleCloudAiplatformV1beta1NearestNeighborQueryEmbedding>,
pub per_crowding_attribute_neighbor_count: Option<i32>,
}Expand description
A query to find a number of similar entities.
This type is not used in any activity, and only used as part of another schema.
Fields
entity_id: Option<String>Optional. The entity id whose similar entities should be searched for. If embedding is set, search will use embedding instead of entity_id.
neighbor_count: Option<i32>Optional. The number of similar entities to be retrieved from feature view for each query.
string_filters: Option<Vec<GoogleCloudAiplatformV1beta1NearestNeighborQueryStringFilter>>Optional. The list of string filters.
parameters: Option<GoogleCloudAiplatformV1beta1NearestNeighborQueryParameters>Optional. Parameters that can be set to tune query on the fly.
numeric_filters: Option<Vec<GoogleCloudAiplatformV1beta1NearestNeighborQueryNumericFilter>>Optional. The list of numeric filters.
embedding: Option<GoogleCloudAiplatformV1beta1NearestNeighborQueryEmbedding>Optional. The embedding vector that be used for similar search.
per_crowding_attribute_neighbor_count: Option<i32>Optional. Crowding is a constraint on a neighbor list produced by nearest neighbor search requiring that no more than sper_crowding_attribute_neighbor_count of the k neighbors returned have the same value of crowding_attribute. It’s used for improving result diversity.