pub struct GoogleCloudAiplatformV1beta1NearestNeighborQueryParameters {
pub leaf_nodes_search_fraction: Option<f64>,
pub approximate_neighbor_candidates: Option<i32>,
}Expand description
Parameters that can be overrided in each query to tune query latency and recall.
This type is not used in any activity, and only used as part of another schema.
Fields
leaf_nodes_search_fraction: Option<f64>Optional. The fraction of the number of leaves to search, set at query time allows user to tune search performance. This value increase result in both search accuracy and latency increase. The value should be between 0.0 and 1.0.
approximate_neighbor_candidates: Option<i32>Optional. The number of neighbors to find via approximate search before exact reordering is performed; if set, this value must be > neighbor_count.