pub struct GoogleCloudAiplatformV1beta1NotebookExecutionJobDataformRepositorySource {
pub dataform_repository_resource_name: Option<String>,
pub commit_sha: Option<String>,
}Expand description
The Dataform Repository containing the input notebook.
This type is not used in any activity, and only used as part of another schema.
Fields
dataform_repository_resource_name: Option<String>The resource name of the Dataform Repository. Format: projects/{project_id}/locations/{location}/repositories/{repository_id}
commit_sha: Option<String>The commit SHA to read repository with. If unset, the file will be read at HEAD.