pub struct GoogleCloudAiplatformV1beta1NotebookExecutionJobGcsNotebookSource {
pub generation: Option<String>,
pub uri: Option<String>,
}Expand description
The Cloud Storage uri for the input notebook.
This type is not used in any activity, and only used as part of another schema.
Fields
generation: Option<String>The version of the Cloud Storage object to read. If unset, the current version of the object is read. See https://cloud.google.com/storage/docs/metadata#generation-number.
uri: Option<String>The Cloud Storage uri pointing to the ipynb file. Format: gs://bucket/notebook_file.ipynb