pub struct GoogleCloudAiplatformV1beta1PythonPackageSpec {
pub args: Option<Vec<String>>,
pub package_uris: Option<Vec<String>>,
pub executor_image_uri: Option<String>,
pub env: Option<Vec<GoogleCloudAiplatformV1beta1EnvVar>>,
pub python_module: Option<String>,
}Expand description
The spec of a Python packaged code.
This type is not used in any activity, and only used as part of another schema.
Fields
args: Option<Vec<String>>Command line arguments to be passed to the Python task.
package_uris: Option<Vec<String>>Required. The Google Cloud Storage location of the Python package files which are the training program and its dependent packages. The maximum number of package URIs is 100.
executor_image_uri: Option<String>Required. The URI of a container image in Artifact Registry that will run the provided Python package. Vertex AI provides a wide range of executor images with pre-installed packages to meet users’ various use cases. See the list of pre-built containers for training. You must use an image from this list.
env: Option<Vec<GoogleCloudAiplatformV1beta1EnvVar>>Environment variables to be passed to the python module. Maximum limit is 100.
python_module: Option<String>Required. The Python module name to run after installing the packages.