pub struct GoogleCloudAiplatformV1beta1QueryDeployedModelsResponse {
pub deployed_models: Option<Vec<GoogleCloudAiplatformV1beta1DeployedModel>>,
pub next_page_token: Option<String>,
pub deployed_model_refs: Option<Vec<GoogleCloudAiplatformV1beta1DeployedModelRef>>,
pub total_endpoint_count: Option<i32>,
pub total_deployed_model_count: Option<i32>,
}Expand description
Response message for QueryDeployedModels method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
deployed_models: Option<Vec<GoogleCloudAiplatformV1beta1DeployedModel>>DEPRECATED Use deployed_model_refs instead.
next_page_token: Option<String>A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.
deployed_model_refs: Option<Vec<GoogleCloudAiplatformV1beta1DeployedModelRef>>References to the DeployedModels that share the specified deploymentResourcePool.
total_endpoint_count: Option<i32>The total number of Endpoints that have DeployedModels on this DeploymentResourcePool.
total_deployed_model_count: Option<i32>The total number of DeployedModels on this DeploymentResourcePool.