pub struct GoogleCloudAiplatformV1beta1QueryReasoningEngineResponse {
pub output: Option<Value>,
}Expand description
Response message for ReasoningEngineExecutionService.Query
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations reasoning engines query projects (response)
Fields
output: Option<Value>Response provided by users in JSON object format.