pub struct GoogleCloudAiplatformV1beta1ReadFeatureValuesResponse {
pub entity_view: Option<GoogleCloudAiplatformV1beta1ReadFeatureValuesResponseEntityView>,
pub header: Option<GoogleCloudAiplatformV1beta1ReadFeatureValuesResponseHeader>,
}Expand description
Response message for FeaturestoreOnlineServingService.ReadFeatureValues.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
entity_view: Option<GoogleCloudAiplatformV1beta1ReadFeatureValuesResponseEntityView>Entity view with Feature values. This may be the entity in the Featurestore if values for all Features were requested, or a projection of the entity in the Featurestore if values for only some Features were requested.
header: Option<GoogleCloudAiplatformV1beta1ReadFeatureValuesResponseHeader>Response header.