pub struct GoogleCloudAiplatformV1beta1ReadFeatureValuesResponseEntityView {
pub data: Option<Vec<GoogleCloudAiplatformV1beta1ReadFeatureValuesResponseEntityViewData>>,
pub entity_id: Option<String>,
}Expand description
Entity view with Feature values.
This type is not used in any activity, and only used as part of another schema.
Fields
data: Option<Vec<GoogleCloudAiplatformV1beta1ReadFeatureValuesResponseEntityViewData>>Each piece of data holds the k requested values for one requested Feature. If no values for the requested Feature exist, the corresponding cell will be empty. This has the same size and is in the same order as the features from the header ReadFeatureValuesResponse.header.
entity_id: Option<String>ID of the requested entity.