pub struct GoogleCloudAiplatformV1beta1ReadFeatureValuesResponseHeader {
pub feature_descriptors: Option<Vec<GoogleCloudAiplatformV1beta1ReadFeatureValuesResponseFeatureDescriptor>>,
pub entity_type: Option<String>,
}Expand description
Response header with metadata for the requested ReadFeatureValuesRequest.entity_type and Features.
This type is not used in any activity, and only used as part of another schema.
Fields
feature_descriptors: Option<Vec<GoogleCloudAiplatformV1beta1ReadFeatureValuesResponseFeatureDescriptor>>List of Feature metadata corresponding to each piece of ReadFeatureValuesResponse.EntityView.data.
entity_type: Option<String>The resource name of the EntityType from the ReadFeatureValuesRequest. Value format: projects/{project}/locations/{location}/featurestores/{featurestore}/entityTypes/{entityType}.