pub struct GoogleCloudAiplatformV1beta1ResourcePool {
pub disk_spec: Option<GoogleCloudAiplatformV1beta1DiskSpec>,
pub id: Option<String>,
pub used_replica_count: Option<i64>,
pub machine_spec: Option<GoogleCloudAiplatformV1beta1MachineSpec>,
pub autoscaling_spec: Option<GoogleCloudAiplatformV1beta1ResourcePoolAutoscalingSpec>,
pub replica_count: Option<i64>,
}Expand description
Represents the spec of a group of resources of the same type, for example machine type, disk, and accelerators, in a PersistentResource.
This type is not used in any activity, and only used as part of another schema.
Fields
disk_spec: Option<GoogleCloudAiplatformV1beta1DiskSpec>Optional. Disk spec for the machine in this node pool.
id: Option<String>Immutable. The unique ID in a PersistentResource for referring to this resource pool. User can specify it if necessary. Otherwise, it’s generated automatically.
used_replica_count: Option<i64>Output only. The number of machines currently in use by training jobs for this resource pool. Will replace idle_replica_count.
machine_spec: Option<GoogleCloudAiplatformV1beta1MachineSpec>Required. Immutable. The specification of a single machine.
autoscaling_spec: Option<GoogleCloudAiplatformV1beta1ResourcePoolAutoscalingSpec>Optional. Optional spec to configure GKE or Ray-on-Vertex autoscaling
replica_count: Option<i64>Optional. The total number of machines to use for this resource pool.