GoogleCloudAiplatformV1beta1RuntimeConfigCodeInterpreterRuntimeConfig

Struct GoogleCloudAiplatformV1beta1RuntimeConfigCodeInterpreterRuntimeConfig 

pub struct GoogleCloudAiplatformV1beta1RuntimeConfigCodeInterpreterRuntimeConfig {
    pub file_output_gcs_bucket: Option<String>,
    pub file_input_gcs_bucket: Option<String>,
}
There is no detailed description.

This type is not used in any activity, and only used as part of another schema.

Fields

file_output_gcs_bucket: Option<String>

Optional. The Cloud Storage bucket for file output of this Extension. If specified, write all output files to the Cloud Storage bucket. Vertex Extension Custom Code Service Agent should be granted file writer to this bucket. If not specified, the file content will be output in response body.

file_input_gcs_bucket: Option<String>

Optional. The Cloud Storage bucket for file input of this Extension. If specified, support input from the Cloud Storage bucket. Vertex Extension Custom Code Service Agent should be granted file reader to this bucket. If not specified, the extension will only accept file contents from request body and reject Cloud Storage file inputs.