pub struct GoogleCloudAiplatformV1beta1SavedQuery {
pub annotation_spec_count: Option<i32>,
pub update_time: Option<DateTime<Utc>>,
pub display_name: Option<String>,
pub create_time: Option<DateTime<Utc>>,
pub support_automl_training: Option<bool>,
pub annotation_filter: Option<String>,
pub metadata: Option<Value>,
pub problem_type: Option<String>,
pub name: Option<String>,
pub etag: Option<String>,
}Expand description
A SavedQuery is a view of the dataset. It references a subset of annotations by problem type and filters.
This type is not used in any activity, and only used as part of another schema.
Fields
annotation_spec_count: Option<i32>Output only. Number of AnnotationSpecs in the context of the SavedQuery.
update_time: Option<DateTime<Utc>>Output only. Timestamp when SavedQuery was last updated.
display_name: Option<String>Required. The user-defined name of the SavedQuery. The name can be up to 128 characters long and can consist of any UTF-8 characters.
create_time: Option<DateTime<Utc>>Output only. Timestamp when this SavedQuery was created.
support_automl_training: Option<bool>Output only. If the Annotations belonging to the SavedQuery can be used for AutoML training.
annotation_filter: Option<String>Output only. Filters on the Annotations in the dataset.
metadata: Option<Value>Some additional information about the SavedQuery.
problem_type: Option<String>Required. Problem type of the SavedQuery. Allowed values: * IMAGE_CLASSIFICATION_SINGLE_LABEL * IMAGE_CLASSIFICATION_MULTI_LABEL * IMAGE_BOUNDING_POLY * IMAGE_BOUNDING_BOX * TEXT_CLASSIFICATION_SINGLE_LABEL * TEXT_CLASSIFICATION_MULTI_LABEL * TEXT_EXTRACTION * TEXT_SENTIMENT * VIDEO_CLASSIFICATION * VIDEO_OBJECT_TRACKING
name: Option<String>Output only. Resource name of the SavedQuery.
etag: Option<String>Used to perform a consistent read-modify-write update. If not set, a blind “overwrite” update happens.