GoogleCloudAiplatformV1beta1StreamingFetchFeatureValuesResponse

Struct GoogleCloudAiplatformV1beta1StreamingFetchFeatureValuesResponse 

pub struct GoogleCloudAiplatformV1beta1StreamingFetchFeatureValuesResponse {
    pub data: Option<Vec<GoogleCloudAiplatformV1beta1FetchFeatureValuesResponse>>,
    pub data_keys_with_error: Option<Vec<GoogleCloudAiplatformV1beta1FeatureViewDataKey>>,
    pub status: Option<GoogleRpcStatus>,
}
Response message for FeatureOnlineStoreService.StreamingFetchFeatureValues.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

data: Option<Vec<GoogleCloudAiplatformV1beta1FetchFeatureValuesResponse>>

no description provided

data_keys_with_error: Option<Vec<GoogleCloudAiplatformV1beta1FeatureViewDataKey>>

no description provided

status: Option<GoogleRpcStatus>

Response status. If OK, then StreamingFetchFeatureValuesResponse.data will be populated. Otherwise StreamingFetchFeatureValuesResponse.data_keys_with_error will be populated with the appropriate data keys. The error only applies to the listed data keys - the stream will remain open for further FeatureOnlineStoreService.StreamingFetchFeatureValuesRequest requests.