pub struct GoogleCloudAiplatformV1beta1StudySpecTransferLearningConfig {
pub disable_transfer_learning: Option<bool>,
pub prior_study_names: Option<Vec<String>>,
}Expand description
This contains flag for manually disabling transfer learning for a study. The names of prior studies being used for transfer learning (if any) are also listed here.
This type is not used in any activity, and only used as part of another schema.
Fields
disable_transfer_learning: Option<bool>Flag to to manually prevent vizier from using transfer learning on a new study. Otherwise, vizier will automatically determine whether or not to use transfer learning.
prior_study_names: Option<Vec<String>>Output only. Names of previously completed studies