pub struct GoogleCloudAiplatformV1beta1SupervisedHyperParameters {
pub epoch_count: Option<i64>,
pub learning_rate_multiplier: Option<f64>,
pub adapter_size: Option<String>,
}Expand description
Hyperparameters for SFT.
This type is not used in any activity, and only used as part of another schema.
Fields
epoch_count: Option<i64>Optional. Number of complete passes the model makes over the entire training dataset during training.
learning_rate_multiplier: Option<f64>Optional. Multiplier for adjusting the default learning rate.
adapter_size: Option<String>Optional. Adapter size for tuning.