pub struct GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution {
pub max: Option<f64>,
pub billable_sum: Option<i64>,
pub mean: Option<f64>,
pub p5: Option<f64>,
pub median: Option<f64>,
pub min: Option<f64>,
pub sum: Option<i64>,
pub p95: Option<f64>,
pub buckets: Option<Vec<GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistributionDatasetBucket>>,
}Expand description
Dataset distribution for Supervised Tuning.
This type is not used in any activity, and only used as part of another schema.
Fields
max: Option<f64>Output only. The maximum of the population values.
billable_sum: Option<i64>Output only. Sum of a given population of values that are billable.
mean: Option<f64>Output only. The arithmetic mean of the values in the population.
p5: Option<f64>Output only. The 5th percentile of the values in the population.
median: Option<f64>Output only. The median of the values in the population.
min: Option<f64>Output only. The minimum of the population values.
sum: Option<i64>Output only. Sum of a given population of values.
p95: Option<f64>Output only. The 95th percentile of the values in the population.
buckets: Option<Vec<GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistributionDatasetBucket>>Output only. Defines the histogram bucket.