pub struct GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistributionDatasetBucket {
pub count: Option<f64>,
pub left: Option<f64>,
pub right: Option<f64>,
}Expand description
Dataset bucket used to create a histogram for the distribution given a population of values.
This type is not used in any activity, and only used as part of another schema.
Fields
count: Option<f64>Output only. Number of values in the bucket.
left: Option<f64>Output only. Left bound of the bucket.
right: Option<f64>Output only. Right bound of the bucket.