pub struct GoogleCloudAiplatformV1beta1SupervisedTuningSpec {
pub validation_dataset_uri: Option<String>,
pub hyper_parameters: Option<GoogleCloudAiplatformV1beta1SupervisedHyperParameters>,
pub training_dataset_uri: Option<String>,
}Expand description
Tuning Spec for Supervised Tuning.
This type is not used in any activity, and only used as part of another schema.
Fields
validation_dataset_uri: Option<String>Optional. Cloud Storage path to file containing validation dataset for tuning. The dataset must be formatted as a JSONL file.
hyper_parameters: Option<GoogleCloudAiplatformV1beta1SupervisedHyperParameters>Optional. Hyperparameters for SFT.
training_dataset_uri: Option<String>Required. Cloud Storage path to file containing training dataset for tuning. The dataset must be formatted as a JSONL file.