pub struct GoogleCloudAiplatformV1beta1SyncFeatureViewResponse {
pub feature_view_sync: Option<String>,
}Expand description
Respose message for FeatureOnlineStoreAdminService.SyncFeatureView.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
feature_view_sync: Option<String>Format: projects/{project}/locations/{location}/featureOnlineStores/{feature_online_store}/featureViews/{feature_view}/featureViewSyncs/{feature_view_sync}