pub struct GoogleCloudAiplatformV1beta1ToolUseExample {
pub response_params: Option<HashMap<String, Value>>,
pub request_params: Option<HashMap<String, Value>>,
pub function_name: Option<String>,
pub extension_operation: Option<GoogleCloudAiplatformV1beta1ToolUseExampleExtensionOperation>,
pub display_name: Option<String>,
pub response_summary: Option<String>,
pub query: Option<String>,
}Expand description
A single example of the tool usage.
This type is not used in any activity, and only used as part of another schema.
Fields
response_params: Option<HashMap<String, Value>>Response parameters generated by this tool.
request_params: Option<HashMap<String, Value>>Request parameters used for executing this tool.
function_name: Option<String>Function name to call.
extension_operation: Option<GoogleCloudAiplatformV1beta1ToolUseExampleExtensionOperation>Extension operation to call.
display_name: Option<String>Required. The display name for example.
response_summary: Option<String>Summary of the tool response to the user query.
query: Option<String>Required. Query that should be routed to this tool.