pub struct GoogleCloudAiplatformV1beta1UploadRagFileConfig {
pub rag_file_chunking_config: Option<GoogleCloudAiplatformV1beta1RagFileChunkingConfig>,
}Expand description
Config for uploading RagFile.
This type is not used in any activity, and only used as part of another schema.
Fields
rag_file_chunking_config: Option<GoogleCloudAiplatformV1beta1RagFileChunkingConfig>Specifies the size and overlap of chunks after uploading RagFile.