pub struct GoogleCloudAiplatformV1beta1WriteFeatureValuesPayload {
pub entity_id: Option<String>,
pub feature_values: Option<HashMap<String, GoogleCloudAiplatformV1beta1FeatureValue>>,
}Expand description
Contains Feature values to be written for a specific entity.
This type is not used in any activity, and only used as part of another schema.
Fields
entity_id: Option<String>Required. The ID of the entity.
feature_values: Option<HashMap<String, GoogleCloudAiplatformV1beta1FeatureValue>>Required. Feature values to be written, mapping from Feature ID to value. Up to 100,000 feature_values entries may be written across all payloads. The feature generation time, aligned by days, must be no older than five years (1825 days) and no later than one year (366 days) in the future.