pub struct GoogleIamV1GetPolicyOptions {
pub requested_policy_version: Option<i32>,
}Expand description
Encapsulates settings provided to GetIamPolicy.
This type is not used in any activity, and only used as part of another schema.
Fields
requested_policy_version: Option<i32>Optional. The maximum policy version that will be used to format the policy. Valid values are 0, 1, and 3. Requests specifying an invalid value will be rejected. Requests for policies with any conditional role bindings must specify version 3. Policies with no conditional role bindings may specify any valid value or leave the field unset. The policy in the response might use the policy version that you specified, or it might use a lower policy version. For example, if you specify version 3, but the policy has no conditional role bindings, the response uses version 1. To learn which resources support conditions in their IAM policies, see the IAM documentation.