pub struct GoogleCloudAiplatformV1beta1ExportModelRequestOutputConfig {
pub image_destination: Option<GoogleCloudAiplatformV1beta1ContainerRegistryDestination>,
pub artifact_destination: Option<GoogleCloudAiplatformV1beta1GcsDestination>,
pub export_format_id: Option<String>,
}Expand description
Output configuration for the Model export.
This type is not used in any activity, and only used as part of another schema.
Fields
image_destination: Option<GoogleCloudAiplatformV1beta1ContainerRegistryDestination>The Google Container Registry or Artifact Registry uri where the Model container image will be copied to. This field should only be set when the exportableContent field of the [Model.supported_export_formats] object contains IMAGE.
artifact_destination: Option<GoogleCloudAiplatformV1beta1GcsDestination>The Cloud Storage location where the Model artifact is to be written to. Under the directory given as the destination a new one with name “model-export--”, where timestamp is in YYYY-MM-DDThh:mm:ss.sssZ ISO-8601 format, will be created. Inside, the Model and any of its supporting files will be written. This field should only be set when the exportableContent field of the [Model.supported_export_formats] object contains ARTIFACT.
export_format_id: Option<String>The ID of the format in which the Model must be exported. Each Model lists the export formats it supports. If no value is provided here, then the first from the list of the Model’s supported formats is used by default.