pub struct GoogleCloudAiplatformV1beta1FindNeighborsRequestQuery {
pub datapoint: Option<GoogleCloudAiplatformV1beta1IndexDatapoint>,
pub approximate_neighbor_count: Option<i32>,
pub per_crowding_attribute_neighbor_count: Option<i32>,
pub neighbor_count: Option<i32>,
pub rrf: Option<GoogleCloudAiplatformV1beta1FindNeighborsRequestQueryRRF>,
pub fraction_leaf_nodes_to_search_override: Option<f64>,
}Expand description
A query to find a number of the nearest neighbors (most similar vectors) of a vector.
This type is not used in any activity, and only used as part of another schema.
Fields
datapoint: Option<GoogleCloudAiplatformV1beta1IndexDatapoint>Required. The datapoint/vector whose nearest neighbors should be searched for.
approximate_neighbor_count: Option<i32>The number of neighbors to find via approximate search before exact reordering is performed. If not set, the default value from scam config is used; if set, this value must be > 0.
per_crowding_attribute_neighbor_count: Option<i32>Crowding is a constraint on a neighbor list produced by nearest neighbor search requiring that no more than some value k’ of the k neighbors returned have the same value of crowding_attribute. It’s used for improving result diversity. This field is the maximum number of matches with the same crowding tag.
neighbor_count: Option<i32>The number of nearest neighbors to be retrieved from database for each query. If not set, will use the default from the service configuration (https://cloud.google.com/vertex-ai/docs/matching-engine/configuring-indexes#nearest-neighbor-search-config).
rrf: Option<GoogleCloudAiplatformV1beta1FindNeighborsRequestQueryRRF>Optional. Represents RRF algorithm that combines search results.
fraction_leaf_nodes_to_search_override: Option<f64>The fraction of the number of leaves to search, set at query time allows user to tune search performance. This value increase result in both search accuracy and latency increase. The value should be between 0.0 and 1.0. If not set or set to 0.0, query uses the default value specified in NearestNeighborSearchConfig.TreeAHConfig.fraction_leaf_nodes_to_search.