pub struct GoogleCloudAiplatformV1beta1ReadFeatureValuesResponseEntityViewData {
pub value: Option<GoogleCloudAiplatformV1beta1FeatureValue>,
pub values: Option<GoogleCloudAiplatformV1beta1FeatureValueList>,
}Expand description
Container to hold value(s), successive in time, for one Feature from the request.
This type is not used in any activity, and only used as part of another schema.
Fields
value: Option<GoogleCloudAiplatformV1beta1FeatureValue>Feature value if a single value is requested.
values: Option<GoogleCloudAiplatformV1beta1FeatureValueList>Feature values list if values, successive in time, are requested. If the requested number of values is greater than the number of existing Feature values, nonexistent values are omitted instead of being returned as empty.