pub struct PublisherModelListCall<'a, C>where
C: 'a,{ /* private fields */ }Expand description
Lists publisher models in Model Garden.
A builder for the models.list method supported by a publisher resource.
It is not used directly, but through a PublisherMethods instance.
Example
Instantiate a resource method builder
// You can configure optional parameters by calling the respective setters at will, and
// execute the final call using `doit()`.
// Values shown here are possibly random and not representative !
let result = hub.publishers().models_list("parent")
.view("ea")
.page_token("ipsum")
.page_size(-88)
.order_by("amet")
.language_code("duo")
.filter("ipsum")
.doit().await;Implementations
Sourceimpl<'a, C> PublisherModelListCall<'a, C>where
C: Connector,
impl<'a, C> PublisherModelListCall<'a, C>where
C: Connector,
Sourcepub async fn doit(
self,
) -> Result<(Response, GoogleCloudAiplatformV1beta1ListPublisherModelsResponse)>
pub async fn doit( self, ) -> Result<(Response, GoogleCloudAiplatformV1beta1ListPublisherModelsResponse)>
Perform the operation you have build so far.
Sourcepub fn parent(self, new_value: &str) -> PublisherModelListCall<'a, C>
pub fn parent(self, new_value: &str) -> PublisherModelListCall<'a, C>
Required. The name of the Publisher from which to list the PublisherModels. Format: publishers/{publisher}
Sets the parent path property to the given value.
Even though the property as already been set when instantiating this call, we provide this method for API completeness.
Sourcepub fn view(self, new_value: &str) -> PublisherModelListCall<'a, C>
pub fn view(self, new_value: &str) -> PublisherModelListCall<'a, C>
Optional. PublisherModel view specifying which fields to read.
Sets the view query property to the given value.
Sourcepub fn page_token(self, new_value: &str) -> PublisherModelListCall<'a, C>
pub fn page_token(self, new_value: &str) -> PublisherModelListCall<'a, C>
Optional. The standard list page token. Typically obtained via ListPublisherModelsResponse.next_page_token of the previous ModelGardenService.ListPublisherModels call.
Sets the page token query property to the given value.
Sourcepub fn page_size(self, new_value: i32) -> PublisherModelListCall<'a, C>
pub fn page_size(self, new_value: i32) -> PublisherModelListCall<'a, C>
Optional. The standard list page size.
Sets the page size query property to the given value.
Sourcepub fn order_by(self, new_value: &str) -> PublisherModelListCall<'a, C>
pub fn order_by(self, new_value: &str) -> PublisherModelListCall<'a, C>
Optional. A comma-separated list of fields to order by, sorted in ascending order. Use “desc” after a field name for descending.
Sets the order by query property to the given value.
Sourcepub fn language_code(self, new_value: &str) -> PublisherModelListCall<'a, C>
pub fn language_code(self, new_value: &str) -> PublisherModelListCall<'a, C>
Optional. The IETF BCP-47 language code representing the language in which the publisher models’ text information should be written in. If not set, by default English (en).
Sets the language code query property to the given value.
Sourcepub fn filter(self, new_value: &str) -> PublisherModelListCall<'a, C>
pub fn filter(self, new_value: &str) -> PublisherModelListCall<'a, C>
Optional. The standard list filter.
Sets the filter query property to the given value.
Sourcepub fn delegate(
self,
new_value: &'a mut dyn Delegate,
) -> PublisherModelListCall<'a, C>
pub fn delegate( self, new_value: &'a mut dyn Delegate, ) -> PublisherModelListCall<'a, C>
The delegate implementation is consulted whenever there is an intermediate result, or if something goes wrong while executing the actual API request.
It should be used to handle progress information, and to implement a certain level of resilience.Sets the delegate property to the given value.
Sourcepub fn param<T>(self, name: T, value: T) -> PublisherModelListCall<'a, C>
pub fn param<T>(self, name: T, value: T) -> PublisherModelListCall<'a, C>
Set any additional parameter of the query string used in the request. It should be used to set parameters which are not yet available through their own setters.
Please note that this method must not be used to set any of the known parameters which have their own setter method. If done anyway, the request will fail.
Additional Parameters
- uploadType (query-string) - Legacy upload protocol for media (e.g. “media”, “multipart”).
- alt (query-string) - Data format for response.
- upload_protocol (query-string) - Upload protocol for media (e.g. “raw”, “multipart”).
- fields (query-string) - Selector specifying which fields to include in a partial response.
- quotaUser (query-string) - Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
- access_token (query-string) - OAuth access token.
- $.xgafv (query-string) - V1 error format.
- oauth_token (query-string) - OAuth 2.0 token for the current user.
- prettyPrint (query-boolean) - Returns response with indentations and line breaks.
- callback (query-string) - JSONP
- key (query-string) - API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
Sourcepub fn add_scope<St>(self, scope: St) -> PublisherModelListCall<'a, C>
pub fn add_scope<St>(self, scope: St) -> PublisherModelListCall<'a, C>
Identifies the authorization scope for the method you are building.
Use this method to actively specify which scope should be used, instead of the default Scope variant
Scope::CloudPlatform.
The scope will be added to a set of scopes. This is important as one can maintain access
tokens for more than one scope.
Usually there is more than one suitable scope to authorize an operation, some of which may encompass more rights than others. For example, for listing resources, a read-only scope will be sufficient, a read-write scope will do as well.
Sourcepub fn add_scopes<I, St>(self, scopes: I) -> PublisherModelListCall<'a, C>
pub fn add_scopes<I, St>(self, scopes: I) -> PublisherModelListCall<'a, C>
Identifies the authorization scope(s) for the method you are building.
See Self::add_scope() for details.
Sourcepub fn clear_scopes(self) -> PublisherModelListCall<'a, C>
pub fn clear_scopes(self) -> PublisherModelListCall<'a, C>
Removes all scopes, and no default scope will be used either.
In this case, you have to specify your API-key using the key parameter (see Self::param()
for details).